@@ -34,7 +34,7 @@ static int gles_init()
 
 		/* Palm SDL has a 16 bit depth buffer by default,
 		 * but I'm going to set it to 8 by default,
-		 * because it's such a nice number (and faster on N900). */
+		 * because it's faster on a N900. */
 		res = SDL_GLES_SetAttribute(SDL_GLES_DEPTH_SIZE, 8);
 		if (res != 0) return res;
 	}
@@ -284,7 +284,7 @@ int SDL_GL_SetAttribute(SDL_GLattr attr, int value)
 			TRACE("Ignoring color buffer alpha size %d", value);
 			return 0;
 		case SDL_GL_DOUBLEBUFFER:
-			TRACE("Ignoring doublebuffer preference");
+			TRACE("Ignoring doublebuffer preference %d", value);
 			/* I wouldn't know how to handle it either way. */
 			return 0;
 		case SDL_GL_DEPTH_SIZE:
@@ -297,6 +297,51 @@ int SDL_GL_SetAttribute(SDL_GLattr attr, int value)
 			return 0;
 		default:
 			WARN("Application asks for unknown GL attribute %u, value %d", attr, value);
+			SDL_SetError("Unknown GL attribute");
+			return 0;
+	}
+}
+
+int SDL_GL_GetAttribute(SDL_GLattr attr, int *value)
+{
+	gles_init();
+	if (!value) {
+		SDL_SetError("Null value");
+		return -1;
+	}
+	switch (attr) {
+		case SDL_GL_CONTEXT_MAJOR_VERSION:
+			switch (desired_version) {
+				case SDL_GLES_VERSION_1_1: *value = 1; break;
+				case SDL_GLES_VERSION_2_0: *value = 2; break;
+				default:                   *value = 0; break;
+			}
+			return 0;
+		case SDL_GL_CONTEXT_MINOR_VERSION:
+			switch (desired_version) {
+				case SDL_GLES_VERSION_1_1: *value = 1; break;
+				case SDL_GLES_VERSION_2_0: *value = 0; break;
+				default:                   *value = 0; break;
+			}
+			return 0;
+		case SDL_GL_RED_SIZE:
+			return SDL_GLES_GetAttribute(SDL_GLES_RED_SIZE, value);
+		case SDL_GL_GREEN_SIZE:
+			return SDL_GLES_GetAttribute(SDL_GLES_GREEN_SIZE, value);
+		case SDL_GL_BLUE_SIZE:
+			return SDL_GLES_GetAttribute(SDL_GLES_BLUE_SIZE, value);
+		case SDL_GL_ALPHA_SIZE:
+			return SDL_GLES_GetAttribute(SDL_GLES_ALPHA_SIZE, value);
+		case SDL_GL_DOUBLEBUFFER:
+			*value = 0;
+			return 0;
+		case SDL_GL_DEPTH_SIZE:
+			return SDL_GLES_GetAttribute(SDL_GLES_DEPTH_SIZE, value);
+		case SDL_GL_STENCIL_SIZE:
+			return SDL_GLES_GetAttribute(SDL_GLES_STENCIL_SIZE, value);
+		default:
+			WARN("Application asks for value of unknown GL attribute %u", attr);
+			SDL_SetError("Unknown GL attribute");
 			return 0;
 	}
 }
@@ -411,7 +456,6 @@ void SDL_SetEventFilter(SDL_EventFilter filter)
 
 Uint8 SDL_GetAppState(void)
 {
-	TRACE("Application state check: %s", app_active ? "active" : "inactive");
 	if (app_active)
 		return SDL_APPMOUSEFOCUS | SDL_APPINPUTFOCUS | SDL_APPACTIVE;
 	else
